@@ -2,7 +2,7 @@
 library(survivoR)
 library(dplyr)
 
-in_progress_seasons <- c("US48", "AU10")
+in_progress_seasons <- c("US49", "US50")
 
 test_that("add_alive works", {
 
@@ -29,7 +29,7 @@ test_that("add_winner works", {
     distinct(version_season, castaway, winner) |>
     summarise(winner = sum(winner)) |>
     pull(winner) |>
-    expect_equal(69)
+    expect_equal(72)
 
 })
 
@@ -43,7 +43,7 @@ test_that("add_jury works", {
     distinct(version_season, castaway, jury) |>
     summarise(jury = sum(jury)) |>
     pull(jury) |>
-    expect_equal(574)
+    expect_equal(597)
 
 })
 
@@ -57,7 +57,7 @@ test_that("add_finalist works", {
     distinct(version_season, castaway, finalist) |>
     summarise(finalist = sum(finalist)) |>
     pull(finalist) |>
-    expect_equal(176)
+    expect_equal(184)
 
 })
 
